@@ -1,12 +1,11 @@
-"""Package init."""
-
 from public import public as _public
+
 from flufl.lock._lockfile import (
-    SEP, Lock, LockError, LockState, TimeOutError, NotLockedError,
-    AlreadyLockedError)
+    AlreadyLockedError, Lock, LockError, LockState, NotLockedError, SEP,
+    TimeOutError)
 
 
-__version__ = '4.0'
+__version__ = '5.0.2'
 
 
 _public(
